==> next-1.1.0.tgz: package/esm/util/withHighlight.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
import { H, HIGHLIGHT_REQUEST_HEADER } from '@highlight-run/node';
export var Highlight = function (options) {
    if (options === void 0) { options = {}; }
    return function (origHandler) {
        return function (req, res) { return __awaiter(void 0, void 0, void 0, function () {
            var processHighlightHeaders, start, e_1, _a, secureSessionId, requestId, delta, _b, secureSessionId, requestId;
            return __generator(this, function (_c) {
                switch (_c.label) {
                    case 0:
                        processHighlightHeaders = function () {
                            if (req.headers && req.headers[HIGHLIGHT_REQUEST_HEADER]) {
                                var _a = "".concat(req.headers[HIGHLIGHT_REQUEST_HEADER]).split('/'), secureSessionId = _a[0], requestId = _a[1];
                                if (secureSessionId && requestId) {
                                    if (!H.isInitialized()) {
                                        H.init(options);
                                    }
                                    return { secureSessionId: secureSessionId, requestId: requestId };
                                }
                            }
                            return { secureSessionId: undefined, requestId: undefined };
                        };
                        start = new Date();
                        _c.label = 1;
                    case 1:
                        _c.trys.push([1, 3, 4, 5]);
                        return [4 /*yield*/, origHandler(req, res)];
                    case 2: return [2 /*return*/, _c.sent()];
                    case 3:
                        e_1 = _c.sent();
                        _a = processHighlightHeaders(), secureSessionId = _a.secureSessionId, requestId = _a.requestId;
                        if (secureSessionId && requestId) {
                            H.consumeEvent(secureSessionId);
                            if (e_1 instanceof Error) {
                                H.consumeError(e_1, secureSessionId, requestId);
                            }
                        }
                        // Because we're going to finish and send the transaction before passing the error onto nextjs, it won't yet
                        // have had a chance to set the status to 500, so unless we do it ourselves now, we'll incorrectly report that
                        // the transaction was error-free
                        res.statusCode = 500;
                        res.statusMessage = 'Internal Server Error';
                        // We rethrow here so that nextjs can do with the error whatever it would normally do. (Sometimes "whatever it
                        // would normally do" is to allow the error to bubble up to the global handlers - another reason we need to mark
                        // the error as already having been captured.)
                        throw e_1;
                    case 4:
                        delta = new Date().getTime() - start.getTime();
                        _b = processHighlightHeaders(), secureSessionId = _b.secureSessionId, requestId = _b.requestId;
                        if (secureSessionId) {
                            H.recordMetric(secureSessionId, 'delayMS', delta, requestId);
                        }
                        return [7 /*endfinally*/];
                    case 5: return [2 /*return*/];
                }
            });
        }); };
    };
};
// this code was assisted by https://github.com/getsentry/sentry-javascript/blob/2f2d099dcc668f12109913caf36097f73a1bc966/packages/nextjs/src/utils/withSentry.ts

==> next-1.1.4.tgz: package/esm/util/withHighlight.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
import { H, HIGHLIGHT_REQUEST_HEADER } from '@highlight-run/node';
export var Highlight = function (options) {
    if (options === void 0) { options = {}; }
    return function (origHandler) {
        return function (req, res) { return __awaiter(void 0, void 0, void 0, function () {
            var processHighlightHeaders, start, e_1, _a, secureSessionId, requestId, delta, _b, secureSessionId, requestId;
            return __generator(this, function (_c) {
                switch (_c.label) {
                    case 0:
                        processHighlightHeaders = function () {
                            if (req.headers && req.headers[HIGHLIGHT_REQUEST_HEADER]) {
                                var _a = "".concat(req.headers[HIGHLIGHT_REQUEST_HEADER]).split('/'), secureSessionId = _a[0], requestId = _a[1];
                                if (secureSessionId && requestId) {
                                    if (!H.isInitialized()) {
                                        H.init(options);
                                    }
                                    return { secureSessionId: secureSessionId, requestId: requestId };
                                }
                            }
                            return { secureSessionId: undefined, requestId: undefined };
                        };
                        start = new Date();
                        _c.label = 1;
                    case 1:
                        _c.trys.push([1, 3, 4, 5]);
                        return [4 /*yield*/, origHandler(req, res)];
                    case 2: return [2 /*return*/, _c.sent()];
                    case 3:
                        e_1 = _c.sent();
                        _a = processHighlightHeaders(), secureSessionId = _a.secureSessionId, requestId = _a.requestId;
                        if (secureSessionId && requestId) {
                            H.consumeEvent(secureSessionId);
                            if (e_1 instanceof Error) {
                                H.consumeError(e_1, secureSessionId, requestId);
                            }
                        }
                        // Because we're going to finish and send the transaction before passing the error onto nextjs, it won't yet
                        // have had a chance to set the status to 500, so unless we do it ourselves now, we'll incorrectly report that
                        // the transaction was error-free
                        res.statusCode = 500;
                        res.statusMessage = 'Internal Server Error';
                        // We rethrow here so that nextjs can do with the error whatever it would normally do. (Sometimes "whatever it
                        // would normally do" is to allow the error to bubble up to the global handlers - another reason we need to mark
                        // the error as already having been captured.)
                        throw e_1;
                    case 4:
                        delta = new Date().getTime() - start.getTime();
                        _b = processHighlightHeaders(), secureSessionId = _b.secureSessionId, requestId = _b.requestId;
                        if (secureSessionId) {
                            H.recordMetric(secureSessionId, 'Latency', delta, requestId);
                        }
                        return [7 /*endfinally*/];
                    case 5: return [2 /*return*/];
                }
            });
        }); };
    };
};
// this code was assisted by https://github.com/getsentry/sentry-javascript/blob/2f2d099dcc668f12109913caf36097f73a1bc966/packages/nextjs/src/utils/withSentry.ts
